from setuptools import setup

setup(
    name="chenxizhang.pyhello",
    version="0.1.1",
    description="A simple hello world Python module",
    py_modules=["pyhello"],
    python_requires=">=3.6",
)
